data2haplohh(hap_file,map_file,min_maf=0,min_perc_geno.hap=100,
min_perc_geno.snp=100,chr.name=NA,popsel=NA,recode.allele=FALSE,
haplotype.in.columns=FALSE)min_maf are discarded)min_perc_geno.hap percent SNPs genotyped are discarded). By default, min_perc_geno.hap=100, hence only fully genotyped haplotypes are retainedmin_perc_geno.snp percent haplotypes are discarded). By default, min_perc_geno.snp=100, hence only fully genotyped SNPs are retainedhap_file is a fastPHASE output and haplotypes originate from different population)haplotype.in.columns is FALSE, as by default), the function automatically checks if the file is in fastPHASE output format. In this latter case, if haplotypes originate from several different population were phased simultaneously (-u fastPHASE option was used), the function ask interactively which population should be considered (a list of population number are proposed) unless specified with the popsel argument.
Map file contains SNPs information in five columns SNP names, chromosome, position, ancestral and derived allele. SNPs must be in the same order as in the haplotype for the chromosome considered. If several chromosomes are represented in the map file, one can provide the name of the chromosome of interest (corresponding to the haplotype under study) with chr.name argument. Haplotype are recoded (if recode.allele option is activated) according to the ancestral and derived allele definition available in the map file (fourth and fifth columns) as :0=missing data, 1=ancestral allele, 2=derived allele. If such a coding is detected, no recoding is performed. Note that Rsb statistics does not consider ancestral and derived allele status information.
Finally, the arguments min\_perc\_geno.hap, min\_perc\_geno.snp and min\_maf are evaluated in this order.
#Copy example files in the current working directory.
make.example.files()
#using the fastPHASE output haplotype example file
hap<-data2haplohh(hap_file="bta12_hapguess_switch.out",map_file="map.inp",
min_maf=0.05,popsel=7,chr.name=12,recode.allele=TRUE)
#using the standard output haplotype example file
hap<-data2haplohh(hap_file="bta12_cgu.hap",map_file="map.inp",
min_maf=0.05,chr.name=12,recode.allele=TRUE)
Run the code above in your browser using DataLab