Learn R Programming

rehh (version 2.0.1)

ihh2ihs: Compute iHS (standardized iHH)

Description

Compute iHS (standardized iHH).

Usage

ihh2ihs(res_ihh,freqbin=0.025,minmaf=0.05)

Arguments

res_ihh
A dataframe with nsnps rows and seven columns as obtained from the scan_hh function applied to the population of interest.
freqbin
Size of the bin to standardize log(iHH1/iHH2) according to the underlying Derived Allele frequency. Allele frequency bins vary from minmaf to 1-minmaf per step of size freqbin. If freqbin is set to 0 (e.g. in the case of a large number of SNPs and few haplotypes), standardization is performed considering each observed frequency as a frequency class.
minmaf
SNPs with a MAF (Minor Allele Frequency) lower than minmaf are discarded from the analysis

Value

The returned value is a list containing two elements

Details

iHS (standardized iHH) are standardized as described in Voight et al. (2006)

References

Gautier, M. and Naves, M. (2011). Footprints of selection in the ancestral admixture of a New World Creole cattle breed. Molecular Ecology, 20, 3128--3143.

Voight, B.F. and Kudaravalli, S. and Wen, X. and Pritchard, J.K. (2006). A map of recent positive selection in the human genome. Plos Biology, 4, e72.

See Also

calc_ehh,scan_hh,distribplot,ihsplot

Examples

Run this code
data(wgscan.cgu) 
## results from a genome scan (44,057 SNPs)
##see ?wgscan.eut and ?wgscan.cgu for details
res.ihs<-ihh2ihs(wgscan.cgu)

Run the code above in your browser using DataLab