| Package: |
| rehh |
| Version: |
| 2.0.0 |
| License: |
| GPL(>=2) |
| Depends: |
| gplots , methods |
Index:
bifurcation.diagram plot of an haplotype bifurcation
diagram
calc_ehh EHH and iHH computations at a
given core SNP
calc_ehhs EHHS and iES computations at a
given core SNP
data2haplohh Converting data into an object
of class haplohh
distribplot Distribution of standardized
iHS, Rsb or XP-EHH values
haplohh_cgu_bta12 Example of an 'haplohh' object
ies2rsb Compute Rsb (standardized ratio of
iES from two populations)
ies2xpehh Compute XP-EHH (standardized ratio of
iES from two populations)
ihh2ihs Compute iHS (standardized iHH)
ihsplot Plot iHS over a genome
make.example.files Generate example input files
rsbplot Plot Rsb over a genome
xpehhplot Plot XP-EHH over a genome
scan_hh Computing EHH based statistics over
a whole chromosome
wgscan.cgu Whole genome scan results for the CGU
(Creole from Guadeloupe island)
wgscan.eut Whole genome scan results for a pool of
European taurine cattle
Gautier M. and Vitalis R. (2012). rehh: An R package to detect footprints of selection in genome-wide SNP data from haplotype structure. Bioinformatics, 28(8), 1176--1177.